summaryrefslogtreecommitdiffstats
path: root/arts/builder
diff options
context:
space:
mode:
Diffstat (limited to 'arts/builder')
-rw-r--r--arts/builder/TODO4
-rw-r--r--arts/builder/createtool.cpp12
-rw-r--r--arts/builder/dirmanager.cpp2
-rw-r--r--arts/builder/drawutils.cpp2
-rw-r--r--arts/builder/execdlg.cpp62
-rw-r--r--arts/builder/execdlg.h5
-rw-r--r--arts/builder/interfacedlg.cpp62
-rw-r--r--arts/builder/interfacedlg.h3
-rw-r--r--arts/builder/main.cpp86
-rw-r--r--arts/builder/main.h1
-rw-r--r--arts/builder/menumaker.cpp10
-rw-r--r--arts/builder/menumaker.h8
-rw-r--r--arts/builder/module.cpp10
-rw-r--r--arts/builder/module.h4
-rw-r--r--arts/builder/mwidget.cpp10
-rw-r--r--arts/builder/mwidget.h3
-rw-r--r--arts/builder/portposdlg.cpp58
-rw-r--r--arts/builder/portposdlg.h3
-rw-r--r--arts/builder/propertypanel.cpp16
-rw-r--r--arts/builder/propertypanel.h3
-rw-r--r--arts/builder/propertypanelbase.ui64
-rw-r--r--arts/builder/qttableview.cpp160
-rw-r--r--arts/builder/qttableview.h45
-rw-r--r--arts/builder/retrievedlg.cpp48
-rw-r--r--arts/builder/retrievedlg.h3
-rw-r--r--arts/builder/structureport.cpp12
26 files changed, 352 insertions, 344 deletions
diff --git a/arts/builder/TODO b/arts/builder/TODO
index 139f22b2..0c8a0859 100644
--- a/arts/builder/TODO
+++ b/arts/builder/TODO
@@ -41,10 +41,10 @@ Wishlist for the artsbuilder app:
this should be very useful in editing objects with lots of properties
(widgets)
-- make _changed signals visible so you can connect the value_changed of a
+- make _changed Q_SIGNALS visible so you can connect the value_changed of a
poti to the frequency of a filter
-- make it possible to edit parent property of widgets (i.e. to insert one
+- make it possible to edit tqparent property of widgets (i.e. to insert one
widget into another)
- add structure property dialog with structure meta information, at least
diff --git a/arts/builder/createtool.cpp b/arts/builder/createtool.cpp
index 77781483..f8d5c7e5 100644
--- a/arts/builder/createtool.cpp
+++ b/arts/builder/createtool.cpp
@@ -43,7 +43,7 @@ CreateTool::CreateTool(ModuleWidget *mwidget)
: MWidgetTool(mwidget)
{
oldCursor = mwidget->cursor();
- mwidget->setCursor(Qt::crossCursor);
+ mwidget->setCursor(TQt::crossCursor);
oldMouseTracking = mwidget->hasMouseTracking();
mwidget->setMouseTracking(true);
@@ -55,7 +55,7 @@ CreateTool::CreateTool(ModuleWidget *mwidget)
CreateTool::~CreateTool()
{
- mwidget->repaint(componentRect);
+ mwidget->tqrepaint(componentRect);
mwidget->setCursor(oldCursor);
mwidget->setMouseTracking(oldMouseTracking);
}
@@ -89,7 +89,7 @@ void CreateTool::mouseMoveEvent(TQMouseEvent *e)
&& mwidget->colXPos(x + width, &cellx2) && mwidget->rowYPos(y + height, &celly2);
if(!posok) return;
- mwidget->repaint(componentRect);
+ mwidget->tqrepaint(componentRect);
componentRect = TQRect(cellx, celly, cellx2 - cellx, celly2 - celly);
TQPainter *p = new TQPainter;
@@ -302,8 +302,8 @@ void ConnectPortsTool::mousePressEvent(TQMouseEvent *e)
void ConnectPortsTool::mouseMoveEvent(TQMouseEvent *e)
{
TQPainter painter(mwidget);
- painter.setPen(Qt::white);
- mwidget->repaint(TQRect(firstPos, lastPos).normalize());
+ painter.setPen(TQt::white);
+ mwidget->tqrepaint(TQRect(firstPos, lastPos).normalize());
painter.drawLine(firstPos, e->pos());
lastPos = e->pos();
}
@@ -334,6 +334,6 @@ void ConnectPortsTool::mouseReleaseEvent(TQMouseEvent *e)
}
}
}
- mwidget->repaint(TQRect(firstPos, lastPos).normalize());
+ mwidget->tqrepaint(TQRect(firstPos, lastPos).normalize());
mwidget->leaveTool(this);
}
diff --git a/arts/builder/dirmanager.cpp b/arts/builder/dirmanager.cpp
index 2f22f104..dae660b2 100644
--- a/arts/builder/dirmanager.cpp
+++ b/arts/builder/dirmanager.cpp
@@ -83,7 +83,7 @@ char *DirManager::directory(const char *subdir, const TQString &desc)
TQString dir = TQFile::decodeName(dirname);
message = i18n("You need the folder %1.\n"
"It will be used to store %2.\nShould I create it now?")
- .arg(dir).arg(desc);
+ .tqarg(dir).tqarg(desc);
if(KMessageBox::questionYesNo(0,message,i18n("aRts Folder Missing"),i18n("Create Folder"),i18n("Do Not Create"))
== KMessageBox::Yes)
diff --git a/arts/builder/drawutils.cpp b/arts/builder/drawutils.cpp
index c2c0ef3f..74dac440 100644
--- a/arts/builder/drawutils.cpp
+++ b/arts/builder/drawutils.cpp
@@ -26,7 +26,7 @@ TQString DrawUtils::cropText(TQPainter *p, TQString text, int maxlen, int& textw
TQString label = text;
while(p->fontMetrics().width(label) > maxlen && label.length() > 0) {
- int i = label.find('_');
+ int i = label.tqfind('_');
if(i != -1)
label = label.mid(i+1);
diff --git a/arts/builder/execdlg.h b/arts/builder/execdlg.h
index 1fbd8069..d916a4ff 100644
--- a/arts/builder/execdlg.h
+++ b/arts/builder/execdlg.h
@@ -31,15 +31,16 @@
class ExecDlg :public TQDialog {
Q_OBJECT
+ TQ_OBJECT
public:
TQTimer *cpuusagetimer;
TQLabel *cpuusagelabel;
- TQVBoxLayout *mainlayout,*sliderlayout;
+ TQVBoxLayout *maintqlayout,*slidertqlayout;
ExecutableStructure *structure;
void start();
void done(int r);
- ExecDlg(TQWidget *parent, ExecutableStructure *structure);
+ ExecDlg(TQWidget *tqparent, ExecutableStructure *structure);
protected slots:
void updateCpuUsage();
diff --git a/arts/builder/interfacedlg.cpp b/arts/builder/interfacedlg.cpp
index 706576d1..9680fc7e 100644
--- a/arts/builder/interfacedlg.cpp
+++ b/arts/builder/interfacedlg.cpp
@@ -41,50 +41,50 @@
using namespace std;
-InterfaceDlg::InterfaceDlg(TQWidget *parent) :TQDialog(parent,"Props", TRUE)
+InterfaceDlg::InterfaceDlg(TQWidget *tqparent) :TQDialog(tqparent,"Props", TRUE)
{
setCaption(i18n("aRts: Structureport View"));
- TQVBoxLayout *mainlayout = new TQVBoxLayout(this);
- //TQHBoxLayout *contentslayout = new TQHBoxLayout;
+ TQVBoxLayout *maintqlayout = new TQVBoxLayout(this);
+ //TQHBoxLayout *contentstqlayout = new TQHBoxLayout;
// object type
/*
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
TQLabel *objectlabel = new TQLabel(this);
TQFont labelfont(objectlabel->font());
labelfont.setPointSize(labelfont.pointSize()*3/2);
objectlabel->setFont(labelfont);
objectlabel->setText(TQString(" ")+i18n("Object type: ")+TQString(port->owner->name())+TQString(" "));
- objectlabel->setAlignment(AlignCenter);
+ objectlabel->tqsetAlignment(AlignCenter);
min_size(objectlabel);
- mainlayout->addWidget(objectlabel);
+ maintqlayout->addWidget(objectlabel);
*/
// port description
/*
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
TQLabel *portlabel = new TQLabel(this);
labelfont.setPointSize(labelfont.pointSize()*4/5);
portlabel->setFont(labelfont);
portlabel->setText(i18n("Port description: ")+ port->description);
min_size(portlabel);
- portlabel->setAlignment(AlignCenter);
- mainlayout->addWidget(portlabel);
+ portlabel->tqsetAlignment(AlignCenter);
+ maintqlayout->addWidget(portlabel);
- int labelwidth = imax(portlabel->sizeHint().width(),objectlabel->sizeHint().width());
+ int labelwidth = imax(portlabel->tqsizeHint().width(),objectlabel->tqsizeHint().width());
portlabel->setMinimumWidth(labelwidth);
objectlabel->setMinimumWidth(labelwidth);
// hruler
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
KSeparator *ruler = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(ruler);
- mainlayout->addSpacing(5);
- mainlayout->addLayout(contentslayout);
+ maintqlayout->addWidget(ruler);
+ maintqlayout->addSpacing(5);
+ maintqlayout->addLayout(contentstqlayout);
*/
// list
@@ -93,26 +93,26 @@ InterfaceDlg::InterfaceDlg(TQWidget *parent) :TQDialog(parent,"Props", TRUE)
update();
listbox->setMinimumSize(340,400);
- mainlayout->addWidget(listbox);
+ maintqlayout->addWidget(listbox);
connect( listbox, TQT_SIGNAL( doubleClicked ( TQListBoxItem *)), this,
TQT_SLOT(accept()));
// hruler
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
KSeparator *ruler2 = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(ruler2);
+ maintqlayout->addWidget(ruler2);
// buttons
- TQHBoxLayout *buttonlayout = new TQHBoxLayout;
- mainlayout->addSpacing(5);
- mainlayout->addLayout(buttonlayout);
- mainlayout->addSpacing(5);
+ TQHBoxLayout *buttontqlayout = new TQHBoxLayout;
+ maintqlayout->addSpacing(5);
+ maintqlayout->addLayout(buttontqlayout);
+ maintqlayout->addSpacing(5);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addSpacing(5);
KButtonBox *bbox = new KButtonBox(this);
- bbox->addButton(KStdGuiItem::help(), this, TQT_SLOT( help() ));
+ bbox->addButton(KStdGuiItem::help(), TQT_TQOBJECT(this), TQT_SLOT( help() ));
bbox->addStretch(1);
TQButton *okbutton = bbox->addButton(KStdGuiItem::ok());
@@ -121,14 +121,14 @@ InterfaceDlg::InterfaceDlg(TQWidget *parent) :TQDialog(parent,"Props", TRUE)
TQButton *cancelbutton = bbox->addButton(KStdGuiItem::cancel());
connect( cancelbutton, TQT_SIGNAL( clicked() ), TQT_SLOT(reject() ) );
- bbox->layout();
+ bbox->tqlayout();
//min_size(bbox);
- buttonlayout->addWidget(bbox);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addWidget(bbox);
+ buttontqlayout->addSpacing(5);
- //mainlayout->activate();
- mainlayout->freeze();
+ //maintqlayout->activate();
+ maintqlayout->freeze();
}
string InterfaceDlg::interfaceName()
@@ -159,10 +159,10 @@ void InterfaceDlg::update(const string& interface, const string& indent)
{
listbox->insertItem((indent + interface).c_str());
- vector<string> *children = Arts::Dispatcher::the()->interfaceRepo().queryChildren(interface);
- for (vector<string>::iterator ci = children->begin(); ci != children->end(); ++ci)
+ vector<string> *tqchildren = Arts::Dispatcher::the()->interfaceRepo().queryChildren(interface);
+ for (vector<string>::iterator ci = tqchildren->begin(); ci != tqchildren->end(); ++ci)
update(ci->c_str(), indent+" ");
- delete children;
+ delete tqchildren;
}
void InterfaceDlg::update()
diff --git a/arts/builder/interfacedlg.h b/arts/builder/interfacedlg.h
index 4524eaaa..235245a7 100644
--- a/arts/builder/interfacedlg.h
+++ b/arts/builder/interfacedlg.h
@@ -32,11 +32,12 @@
class InterfaceDlg :public TQDialog {
Q_OBJECT
+ TQ_OBJECT
protected:
TQListBox *listbox;
public:
- InterfaceDlg(TQWidget *parent);
+ InterfaceDlg(TQWidget *tqparent);
std::string interfaceName();
void update(const std::string& interface, const std::string& indent);
diff --git a/arts/builder/main.cpp b/arts/builder/main.cpp
index 4630f2f7..558f650c 100644
--- a/arts/builder/main.cpp
+++ b/arts/builder/main.cpp
@@ -251,17 +251,17 @@ ArtsBuilderWindow::ArtsBuilderWindow(const char *name)
*/
#if 000
- connect(menubar, TQT_SIGNAL(highlighted(int)), this, TQT_SLOT(activateMenu(int)));
+ connect(menubar, TQT_SIGNAL(highlighted(int)), TQT_TQOBJECT(this), TQT_SLOT(activateMenu(int)));
connect(m_view, TQT_SIGNAL(activated(int)), modulewidget, TQT_SLOT(setZoom(int)));
- connect(m_ports, TQT_SIGNAL(activated(int)), this, TQT_SLOT(addPort(int)));
- connect(m_file_new, TQT_SIGNAL(activated(int)), this, TQT_SLOT(fileNew(int)));
+ connect(m_ports, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(addPort(int)));
+ connect(m_file_new, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(fileNew(int)));
- //connect(m_modules, TQT_SIGNAL(activated(int)), this, TQT_SLOT(addModule(int)));
+ //connect(m_modules, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(addModule(int)));
/*
- connect(m_modules_synth, TQT_SIGNAL(activated(int)), this, TQT_SLOT(addModule(int)));
- connect(m_modules_gui, TQT_SIGNAL(activated(int)), this, TQT_SLOT(addModule(int)));
- connect(m_modules_instruments, TQT_SIGNAL(activated(int)), this, TQT_SLOT(addModule(int)));
- connect(m_modules_other, TQT_SIGNAL(activated(int)), this, TQT_SLOT(addModule(int)));
+ connect(m_modules_synth, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(addModule(int)));
+ connect(m_modules_gui, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(addModule(int)));
+ connect(m_modules_instruments, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(addModule(int)));
+ connect(m_modules_other, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(addModule(int)));
*/
connect(kapp, TQT_SIGNAL(lastWindowClosed()), this , TQT_SLOT(quit()));
@@ -269,7 +269,7 @@ ArtsBuilderWindow::ArtsBuilderWindow(const char *name)
#endif
arts_debug("PORT: activatemenu");
- connect(menumaker, TQT_SIGNAL(activated(const char *)), this, TQT_SLOT(addModule(const char *)));
+ connect(menumaker, TQT_SIGNAL(activated(const char *)), TQT_TQOBJECT(this), TQT_SLOT(addModule(const char *)));
fillModuleMenu();
arts_debug("PORT: activatemenu ok");
setupActions();
@@ -279,11 +279,11 @@ ArtsBuilderWindow::ArtsBuilderWindow(const char *name)
// connect to aboutToShow to correctly show state of dockwidget there:
TQPopupMenu *viewmenu = (TQPopupMenu*)factory()->container("view", this);
if (viewmenu)
- connect(viewmenu, TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(viewMenuAboutToShow()));
+ connect(viewmenu, TQT_SIGNAL(aboutToShow()), TQT_TQOBJECT(this), TQT_SLOT(viewMenuAboutToShow()));
else
arts_debug("view menu not found!");
- m_filename = TQString::null;
+ m_filename = TQString();
setModified(false);
installEventFilter(propertyPanel);
@@ -292,55 +292,55 @@ ArtsBuilderWindow::ArtsBuilderWindow(const char *name)
void ArtsBuilderWindow::setupActions()
{
// File menu
- KStdAction::openNew(this, TQT_SLOT(fileNew()), actionCollection());
+ KStdAction::openNew(TQT_TQOBJECT(this), TQT_SLOT(fileNew()), actionCollection());
- (void)new KAction(i18n("Open Session..."), 0, this, TQT_SLOT(openSession()),
+ (void)new KAction(i18n("Open Session..."), 0, TQT_TQOBJECT(this), TQT_SLOT(openSession()),
actionCollection(), "file_open_session");
- KStdAction::open(this, TQT_SLOT(open()), actionCollection());
- (void)new KAction(i18n("Open E&xample..."), Qt::CTRL + Qt::Key_X, this, TQT_SLOT(openExample()),
+ KStdAction::open(TQT_TQOBJECT(this), TQT_SLOT(open()), actionCollection());
+ (void)new KAction(i18n("Open E&xample..."), TQt::CTRL + TQt::Key_X, TQT_TQOBJECT(this), TQT_SLOT(openExample()),
actionCollection(), "file_open_example");
- KStdAction::save(this, TQT_SLOT(save()), actionCollection());
- KStdAction::saveAs(this, TQT_SLOT(saveAs()), actionCollection());
- (void)new KAction(i18n("&Retrieve From Server..."), Qt::CTRL + Qt::Key_R, this, TQT_SLOT(retrieve()),
+ KStdAction::save(TQT_TQOBJECT(this), TQT_SLOT(save()), actionCollection());
+ KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(saveAs()), actionCollection());
+ (void)new KAction(i18n("&Retrieve From Server..."), TQt::CTRL + TQt::Key_R, TQT_TQOBJECT(this), TQT_SLOT(retrieve()),
actionCollection(), "file_retrieve_from_server");
- (void)new KAction(i18n("&Execute Structure"), "artsbuilderexecute", Qt::CTRL + Qt::Key_E, this, TQT_SLOT(execute()),
+ (void)new KAction(i18n("&Execute Structure"), "artsbuilderexecute", TQt::CTRL + TQt::Key_E, TQT_TQOBJECT(this), TQT_SLOT(execute()),
actionCollection(), "file_execute_structure");
- (void)new KAction(i18n("&Rename Structure..."), Qt::CTRL + Qt::Key_R, this, TQT_SLOT(rename()),
+ (void)new KAction(i18n("&Rename Structure..."), TQt::CTRL + TQt::Key_R, TQT_TQOBJECT(this), TQT_SLOT(rename()),
actionCollection(), "file_rename_structure");
- (void)new KAction(i18n("&Publish Structure"), Qt::CTRL + Qt::Key_P, this, TQT_SLOT(publish()),
+ (void)new KAction(i18n("&Publish Structure"), TQt::CTRL + TQt::Key_P, TQT_TQOBJECT(this), TQT_SLOT(publish()),
actionCollection(), "file_publish_structure");
- KStdAction::quit(this, TQT_SLOT(close()), actionCollection());
+ KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection());
// Edit menu
- (void)new KAction(i18n("&Delete"), Qt::Key_Delete, modulewidget, TQT_SLOT(delModule()),
+ (void)new KAction(i18n("&Delete"), TQt::Key_Delete, TQT_TQOBJECT(modulewidget), TQT_SLOT(delModule()),
actionCollection(), "edit_delete");
- KStdAction::selectAll(modulewidget, TQT_SLOT(selectAll()), actionCollection());
+ KStdAction::selectAll(TQT_TQOBJECT(modulewidget), TQT_SLOT(selectAll()), actionCollection());
// View menu
viewPropertiesAction= new KToggleAction(i18n("&Property Panel"), 0,
- propertyDock, TQT_SLOT(changeHideShowState()),
+ TQT_TQOBJECT(propertyDock), TQT_SLOT(changeHideShowState()),
actionCollection(), "view_properties");
- (void)new KAction(i18n("200%"), 0, this, TQT_SLOT(viewAt200()),
+ (void)new KAction(i18n("200%"), 0, TQT_TQOBJECT(this), TQT_SLOT(viewAt200()),
actionCollection(), "view_200");
- (void)new KAction(i18n("150%"), 0, this, TQT_SLOT(viewAt150()),
+ (void)new KAction(i18n("150%"), 0, TQT_TQOBJECT(this), TQT_SLOT(viewAt150()),
actionCollection(), "view_150");
- (void)new KAction(i18n("100%"), 0, this, TQT_SLOT(viewAt100()),
+ (void)new KAction(i18n("100%"), 0, TQT_TQOBJECT(this), TQT_SLOT(viewAt100()),
actionCollection(), "view_100");
- (void)new KAction(i18n("50%"), 0, this, TQT_SLOT(viewAt50()),
+ (void)new KAction(i18n("50%"), 0, TQT_TQOBJECT(this), TQT_SLOT(viewAt50()),
actionCollection(), "view_50");
// Ports menu
- (void)new KAction(i18n("Create IN Audio Signal"), 0, this, TQT_SLOT(createInAudioSignal()),
+ (void)new KAction(i18n("Create IN Audio Signal"), 0, TQT_TQOBJECT(this), TQT_SLOT(createInAudioSignal()),
actionCollection(), "ports_create_in_audio_signal");
- (void)new KAction(i18n("Create OUT Audio Signal"), 0, this, TQT_SLOT(createOutAudioSignal()),
+ (void)new KAction(i18n("Create OUT Audio Signal"), 0, TQT_TQOBJECT(this), TQT_SLOT(createOutAudioSignal()),
actionCollection(), "ports_create_out_audio_signal");
- (void)new KAction(i18n("Create IN String Property"), 0, this, TQT_SLOT(createInStringProperty()),
+ (void)new KAction(i18n("Create IN String Property"), 0, TQT_TQOBJECT(this), TQT_SLOT(createInStringProperty()),
actionCollection(), "ports_create_in_string_property");
- (void)new KAction(i18n("Create IN Audio Property"), 0, this, TQT_SLOT(createInAudioProperty()),
+ (void)new KAction(i18n("Create IN Audio Property"), 0, TQT_TQOBJECT(this), TQT_SLOT(createInAudioProperty()),
actionCollection(), "ports_create_in_audio_property");
- (void)new KAction(i18n("Implement Interface..."), 0, this, TQT_SLOT(addInterface()),
+ (void)new KAction(i18n("Implement Interface..."), 0, TQT_TQOBJECT(this), TQT_SLOT(addInterface()),
actionCollection(), "ports_implement_interface");
- (void)new KAction(i18n("Change Positions/Names..."), 0, this, TQT_SLOT(changePortPositions()),
+ (void)new KAction(i18n("Change Positions/Names..."), 0, TQT_TQOBJECT(this), TQT_SLOT(changePortPositions()),
actionCollection(), "ports_change_positions");
}
@@ -441,7 +441,7 @@ void ArtsBuilderWindow::publish()
checkName();
structure->publish();
KMessageBox::information(this,
- i18n("The structure has been published as: '%1' on the server.").arg( structure->name().c_str() ));
+ i18n("The structure has been published as: '%1' on the server.").tqarg( structure->name().c_str() ));
}
TQString ArtsBuilderWindow::getOpenFilename(const char *pattern, const char *initialDir)
@@ -474,7 +474,7 @@ void ArtsBuilderWindow::fileNew()
propertyPanel->setSelectedComponent(0);
structure->clear();
modulewidget->reInit();
- m_filename = TQString::null;
+ m_filename = TQString();
setModified(false);
}
@@ -532,7 +532,7 @@ void ArtsBuilderWindow::openSession()
execDlg->start();
execDlg->show();
- connect(execDlg, TQT_SIGNAL(ready()), this, TQT_SLOT(endexecute()));
+ connect(execDlg, TQT_SIGNAL(ready()), TQT_TQOBJECT(this), TQT_SLOT(endexecute()));
hide();
// m_filename = filename; FIXME: DOESN'T THIS BELONG HERE?
@@ -587,7 +587,7 @@ bool ArtsBuilderWindow::save(TQString filename)
if(file.status()) {
KMessageBox::sorry(this,
i18n("The file '%1' could not be opened for writing: %2")
- .arg(filename).arg(strerror(file.status())),
+ .tqarg(filename).tqarg(strerror(file.status())),
i18n("aRts Warning"));
return false;
}
@@ -597,7 +597,7 @@ bool ArtsBuilderWindow::save(TQString filename)
if(!file.close()) {
KMessageBox::sorry(this,
i18n("Saving to file '%1' could not be finished correctly: %2")
- .arg(filename).arg(strerror(file.status())),
+ .tqarg(filename).tqarg(strerror(file.status())),
i18n("aRts Warning"));
return false;
}
@@ -674,7 +674,7 @@ void ArtsBuilderWindow::execute()
execDlg->start();
execDlg->show();
- connect(execDlg, TQT_SIGNAL(ready()), this, TQT_SLOT(endexecute()));
+ connect(execDlg, TQT_SIGNAL(ready()), TQT_TQOBJECT(this), TQT_SLOT(endexecute()));
hide();
}
@@ -838,7 +838,7 @@ bool ArtsBuilderWindow::promptToSave()
return true;
query = KMessageBox::warningYesNoCancel(this,
- i18n("The current structure has been modified.\nWould you like to save it?"), TQString::null, KStdGuiItem::save(), KStdGuiItem::discard());
+ i18n("The current structure has been modified.\nWould you like to save it?"), TQString(), KStdGuiItem::save(), KStdGuiItem::discard());
result = false;
switch(query)
@@ -872,7 +872,7 @@ ArtsBuilderApp::ArtsBuilderApp(TQString filename)
mainWindow->open(filename);
} else {
KMessageBox::sorry(0,
- i18n("The specified file '%1' does not exist.").arg(filename),
+ i18n("The specified file '%1' does not exist.").tqarg(filename),
i18n("aRts Warning"));
}
}
diff --git a/arts/builder/main.h b/arts/builder/main.h
index e9c17391..b11cf224 100644
--- a/arts/builder/main.h
+++ b/arts/builder/main.h
@@ -40,6 +40,7 @@ class KToggleAction;
class ArtsBuilderWindow: public KDockMainWindow
{
Q_OBJECT
+ TQ_OBJECT
protected:
KDockWidget* mainDock;
diff --git a/arts/builder/menumaker.cpp b/arts/builder/menumaker.cpp
index 2aed8401..dd08589d 100644
--- a/arts/builder/menumaker.cpp
+++ b/arts/builder/menumaker.cpp
@@ -5,11 +5,11 @@
using namespace std;
-MenuEntry::MenuEntry(MenuMaker *menumaker, KActionMenu *parent, const char *text)
+MenuEntry::MenuEntry(MenuMaker *menumaker, KActionMenu *tqparent, const char *text)
: menumaker(menumaker), text(text)
{
action = new KAction(TQString::fromLocal8Bit(text));
- parent->insert(action);
+ tqparent->insert(action);
connect(action, TQT_SIGNAL(activated()), this, TQT_SLOT(activated()));
}
@@ -95,7 +95,7 @@ void MenuMaker::addCategory(const TQString& name, const char *prefix)
/* 000 */
/*connect(newMenu,TQT_SIGNAL(activated(int)),this,TQT_SLOT(menuactivated(int)));
pc->menu()->insertItem(catname(name).c_str(), newMenu, CAT_MAGIC_ID);*/
- arts_debug("inserting a menu called '%s' in the parent menu '%s'",
+ arts_debug("inserting a menu called '%s' in the tqparent menu '%s'",
catname(name).local8Bit().data(),pc->name().local8Bit().data());
categories.push_back(new MenuCategory(name,prefix,newMenu));
}
@@ -148,7 +148,7 @@ TQString MenuMaker::basename(const TQString& name)
{
TQString result = "";
- int i = name.findRev('/');
+ int i = name.tqfindRev('/');
if(i != -1)
result = name.left(i);
@@ -159,7 +159,7 @@ TQString MenuMaker::basename(const TQString& name)
TQString MenuMaker::catname(const TQString& name)
{
- int i = name.findRev('/');
+ int i = name.tqfindRev('/');
if(i >= 0)
return name.mid(i+1);
diff --git a/arts/builder/menumaker.h b/arts/builder/menumaker.h
index f2481a2f..583854f6 100644
--- a/arts/builder/menumaker.h
+++ b/arts/builder/menumaker.h
@@ -8,9 +8,10 @@
class MenuMaker;
-class MenuEntry : public QObject
+class MenuEntry : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
protected:
MenuMaker *menumaker;
@@ -18,7 +19,7 @@ protected:
TQCString text;
public:
- MenuEntry(MenuMaker *menumaker, KActionMenu *parent, const char *text);
+ MenuEntry(MenuMaker *menumaker, KActionMenu *tqparent, const char *text);
public slots:
void activated();
@@ -43,9 +44,10 @@ public:
bool matches(const char *item);
};
-class MenuMaker :public QObject
+class MenuMaker :public TQObject
{
Q_OBJECT
+ TQ_OBJECT
std::list<MenuCategory *> categories;
public:
diff --git a/arts/builder/module.cpp b/arts/builder/module.cpp
index 5432492e..7d9581bf 100644
--- a/arts/builder/module.cpp
+++ b/arts/builder/module.cpp
@@ -128,7 +128,7 @@ void Module::initModule()
_pixmap = new TQPixmap(iconloader.loadIcon(iconname, KIcon::User));
if(!_pixmap->height())
{
- iconname.replace( iconname.length() - 4, 3, "png" );
+ iconname.tqreplace( iconname.length() - 4, 3, "png" );
delete _pixmap;
_pixmap = new TQPixmap(iconloader.loadIcon(iconname, KIcon::User));
if( !_pixmap->height() )
@@ -243,8 +243,8 @@ void Module::drawSegment(TQPainter *p, int cellsize, int segment)
mcolor = TQColor(100, 100, 100);
mcolorlight = TQColor(160, 160, 160);
}
- TQColorGroup g( Qt::white, Qt::blue, mcolorlight, mcolor.dark(), mcolor,
- Qt::black, Qt::black );
+ TQColorGroup g( TQt::white, TQt::blue, mcolorlight, mcolor.dark(), mcolor,
+ TQt::black, TQt::black );
TQBrush fill( mcolor );
TQPen textpen(TQColor(255, 255, 180), 1);
@@ -373,7 +373,7 @@ void Module::drawSegment(TQPainter *p, int cellsize, int segment)
if(selected())
{
- TQPen pen(Qt::white, 1, Qt::DotLine);
+ TQPen pen(TQt::white, 1, TQt::DotLine);
p->setPen(pen);
p->drawLine(0, 0, cellsize - 1, 0);
@@ -413,7 +413,7 @@ ModulePort *Module::portAt(int segment, int x, int y)
if(port)
{
TQPoint clickpoint(x, y);
- if(port->clickrect.contains(clickpoint)) return port;
+ if(port->clickrect.tqcontains(clickpoint)) return port;
}
}
return 0;
diff --git a/arts/builder/module.h b/arts/builder/module.h
index 6fbff74d..44466bc0 100644
--- a/arts/builder/module.h
+++ b/arts/builder/module.h
@@ -46,8 +46,8 @@ public:
bool selected;
StructureComponent *owner;
- QString description;
- QRect clickrect;
+ TQString description;
+ TQRect clickrect;
ConnType conntype;
Direction direction;
int drawsegment;
diff --git a/arts/builder/mwidget.cpp b/arts/builder/mwidget.cpp
index 808b3bcf..5ab19fe7 100644
--- a/arts/builder/mwidget.cpp
+++ b/arts/builder/mwidget.cpp
@@ -133,7 +133,7 @@ void ModuleWidget::mousePressEvent( TQMouseEvent *e )
return;
}
- if( e->button() == LeftButton )
+ if( e->button() == Qt::LeftButton )
{
StructureComponent *component;
ModulePort *port;
@@ -594,7 +594,7 @@ void ModuleWidget::delModule()
if(KMessageBox::warningContinueCancel(0,
i18n("Delete %n selected module, port or connection? (No undo possible.)",
"Delete %n selected modules, ports and connections? (No undo possible.)",
- numSelected), TQString::null, i18n("&Delete")) == KMessageBox::Continue)
+ numSelected), TQString(), i18n("&Delete")) == KMessageBox::Continue)
{
selectPort(0L);
emit componentSelected(0);
@@ -608,8 +608,8 @@ void ModuleWidget::autoRedrawRouter()
if(autorouter->needRedraw()) redrawAll();
}
-ModuleWidget::ModuleWidget(Structure *structure, TQWidget *parent, const char *name, WFlags f)
- : QtTableView( parent, name, f),
+ModuleWidget::ModuleWidget(Structure *structure, TQWidget *tqparent, const char *name, WFlags f)
+ : QtTableView( tqparent, name, f),
updateDepth( 0 ),
activeTool( 0L ),
structure( structure ),
@@ -627,7 +627,7 @@ ModuleWidget::ModuleWidget(Structure *structure, TQWidget *parent, const char *n
setTableFlags(Tbl_autoScrollBars);
setZoom(100);
- setFocusPolicy( NoFocus );
+ setFocusPolicy( TQ_NoFocus );
arts_debug("PORT: mw; bgmode");
setBackgroundMode(NoBackground);
diff --git a/arts/builder/mwidget.h b/arts/builder/mwidget.h
index 8f92c946..b3b41b78 100644
--- a/arts/builder/mwidget.h
+++ b/arts/builder/mwidget.h
@@ -34,6 +34,7 @@ class MWidgetTool;
class ModuleWidget :public QtTableView, public StructureCanvas
{
Q_OBJECT
+ TQ_OBJECT
friend class MWidgetTool;
friend class CreateTool;
friend class CreateInterfaceTool;
@@ -108,7 +109,7 @@ public:
TQPoint componentPos(const StructureComponent *component) const;
TQPoint portPos(const ModulePort *port) const;
- ModuleWidget( Structure *structure, TQWidget *parent = 0,
+ ModuleWidget( Structure *structure, TQWidget *tqparent = 0,
const char *name = 0, WFlags f = 0);
~ModuleWidget();
diff --git a/arts/builder/portposdlg.cpp b/arts/builder/portposdlg.cpp
index 72bd4379..ecd877c9 100644
--- a/arts/builder/portposdlg.cpp
+++ b/arts/builder/portposdlg.cpp
@@ -40,52 +40,52 @@
using namespace std;
-PortPosDlg::PortPosDlg(TQWidget *parent, Structure *structure) :TQDialog(parent,"Props", TRUE)
+PortPosDlg::PortPosDlg(TQWidget *tqparent, Structure *structure) :TQDialog(tqparent,"Props", TRUE)
{
this->structure = structure;
setCaption(i18n("aRts: Structureport View"));
- TQVBoxLayout *mainlayout = new TQVBoxLayout(this);
- //TQHBoxLayout *contentslayout = new TQHBoxLayout;
+ TQVBoxLayout *maintqlayout = new TQVBoxLayout(this);
+ //TQHBoxLayout *contentstqlayout = new TQHBoxLayout;
// object type
/*
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
TQLabel *objectlabel = new TQLabel(this);
TQFont labelfont(objectlabel->font());
labelfont.setPointSize(labelfont.pointSize()*3/2);
objectlabel->setFont(labelfont);
objectlabel->setText(TQString(" ")+i18n("Object type: ")+TQString(port->owner->name())+TQString(" "));
- objectlabel->setAlignment(AlignCenter);
+ objectlabel->tqsetAlignment(AlignCenter);
min_size(objectlabel);
- mainlayout->addWidget(objectlabel);
+ maintqlayout->addWidget(objectlabel);
*/
// port description
/*
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
TQLabel *portlabel = new TQLabel(this);
labelfont.setPointSize(labelfont.pointSize()*4/5);
portlabel->setFont(labelfont);
portlabel->setText(i18n("Port description: ")+ port->description);
min_size(portlabel);
- portlabel->setAlignment(AlignCenter);
- mainlayout->addWidget(portlabel);
+ portlabel->tqsetAlignment(AlignCenter);
+ maintqlayout->addWidget(portlabel);
- int labelwidth = imax(portlabel->sizeHint().width(),objectlabel->sizeHint().width());
+ int labelwidth = imax(portlabel->tqsizeHint().width(),objectlabel->tqsizeHint().width());
portlabel->setMinimumWidth(labelwidth);
objectlabel->setMinimumWidth(labelwidth);
// hruler
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
KSeparator *ruler = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(ruler);
- mainlayout->addSpacing(5);
- mainlayout->addLayout(contentslayout);
+ maintqlayout->addWidget(ruler);
+ maintqlayout->addSpacing(5);
+ maintqlayout->addLayout(contentstqlayout);
*/
// list
@@ -94,24 +94,24 @@ PortPosDlg::PortPosDlg(TQWidget *parent, Structure *structure) :TQDialog(parent,
update();
listbox->setMinimumSize(100,200);
- mainlayout->addWidget(listbox);
+ maintqlayout->addWidget(listbox);
// hruler
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
KSeparator *ruler2 = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(ruler2);
+ maintqlayout->addWidget(ruler2);
// buttons
- TQHBoxLayout *buttonlayout = new TQHBoxLayout;
- mainlayout->addSpacing(5);
- mainlayout->addLayout(buttonlayout);
- mainlayout->addSpacing(5);
+ TQHBoxLayout *buttontqlayout = new TQHBoxLayout;
+ maintqlayout->addSpacing(5);
+ maintqlayout->addLayout(buttontqlayout);
+ maintqlayout->addSpacing(5);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addSpacing(5);
KButtonBox *bbox = new KButtonBox(this);
- bbox->addButton(KStdGuiItem::help(), this, TQT_SLOT( help() ));
+ bbox->addButton(KStdGuiItem::help(), TQT_TQOBJECT(this), TQT_SLOT( help() ));
bbox->addStretch(1);
KIconLoader iconloader;
@@ -133,14 +133,14 @@ PortPosDlg::PortPosDlg(TQWidget *parent, Structure *structure) :TQDialog(parent,
TQButton *cancelbutton = bbox->addButton(i18n("Cancel"));
connect( cancelbutton, TQT_SIGNAL( clicked() ), TQT_SLOT(reject() ) );
*/
- bbox->layout();
+ bbox->tqlayout();
//min_size(bbox);
- buttonlayout->addWidget(bbox);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addWidget(bbox);
+ buttontqlayout->addSpacing(5);
- //mainlayout->activate();
- mainlayout->freeze();
+ //maintqlayout->activate();
+ maintqlayout->freeze();
}
void PortPosDlg::raise()
@@ -247,7 +247,7 @@ void PortPosDlg::update()
}
}
}
- listbox->repaint();
+ listbox->tqrepaint();
}
void PortPosDlg::help()
diff --git a/arts/builder/portposdlg.h b/arts/builder/portposdlg.h
index 1adc997c..aa61bad1 100644
--- a/arts/builder/portposdlg.h
+++ b/arts/builder/portposdlg.h
@@ -32,13 +32,14 @@
class PortPosDlg :public TQDialog {
Q_OBJECT
+ TQ_OBJECT
protected:
Structure *structure;
TQListBox *listbox;
std::vector<StructurePort *> listports;
public:
- PortPosDlg(TQWidget *parent, Structure *structure);
+ PortPosDlg(TQWidget *tqparent, Structure *structure);
void update();
public slots:
diff --git a/arts/builder/propertypanel.cpp b/arts/builder/propertypanel.cpp
index cca2ee5d..8e543a5f 100644
--- a/arts/builder/propertypanel.cpp
+++ b/arts/builder/propertypanel.cpp
@@ -36,8 +36,8 @@
#include <arts/debug.h>
-PropertyPanel::PropertyPanel( TQWidget* parent, const char* name, WFlags fl )
- : PropertyPanelBase( parent, name, fl ),
+PropertyPanel::PropertyPanel( TQWidget* tqparent, const char* name, WFlags fl )
+ : PropertyPanelBase( tqparent, name, fl ),
component(0L),
port(0L)
{
@@ -115,7 +115,7 @@ void PropertyPanel::setSelectedComponent( StructureComponent *component )
if(component->pixmap())
{
moduleIconLabel->setPixmap( *component->pixmap() );
- moduleIconLabel->setMinimumSize( moduleIconLabel->sizeHint() );
+ moduleIconLabel->setMinimumSize( moduleIconLabel->tqsizeHint() );
moduleIconLabel->show();
}
else
@@ -128,11 +128,11 @@ void PropertyPanel::setSelectedComponent( StructureComponent *component )
it != modulePorts.end(); it++)
{
TQString portTitle = (*it)->description
- + TQString(" (%1)").arg( (*it)->PortDesc.type().direction == Arts::output ?
+ + TQString(" (%1)").tqarg( (*it)->PortDesc.type().direction == Arts::output ?
i18n("OUTPUT") : i18n("INPUT") );
portCombo->insertItem( portTitle );
}
- //portCombo->setMinimumSize( portCombo->sizeHint() );
+ //portCombo->setMinimumSize( portCombo->tqsizeHint() );
setEnabled(true);
}
}
@@ -156,7 +156,7 @@ void PropertyPanel::setSelectedPort( ModulePort *port )
// select port in combobox - bah, should be easier ;-)
portCombo->setCurrentItem(
portCombo->listBox()->index(
- portCombo->listBox()->findItem( port->description + " (" ) ) );
+ portCombo->listBox()->tqfindItem( port->description + " (" ) ) );
}
else
{
@@ -341,10 +341,10 @@ bool PropertyPanel::eventFilter( TQObject *o, TQEvent *e )
{
if( port && !constantValueEdit->hasFocus() && (e->type() == TQEvent::KeyPress) ) {
// kdDebug() << TQString(" ..is KeyPress") << endl;
- TQString entered = static_cast<TQKeyEvent *>(e)->text();
+ TQString entered = TQT_TQKEYEVENT(e)->text();
bool goodString = entered.length() > 0;
-// kdDebug() << TQString("pressed '%1'").arg(entered) << endl;
+// kdDebug() << TQString("pressed '%1'").tqarg(entered) << endl;
for( unsigned int i = 0; i < entered.length(); i++)
goodString = goodString && entered[i].isLetterOrNumber();
diff --git a/arts/builder/propertypanel.h b/arts/builder/propertypanel.h
index 3603ddad..07ce3f90 100644
--- a/arts/builder/propertypanel.h
+++ b/arts/builder/propertypanel.h
@@ -33,9 +33,10 @@ class ModulePort;
class PropertyPanel: public PropertyPanelBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- PropertyPanel( TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
+ PropertyPanel( TQWidget* tqparent = 0, const char* name = 0, WFlags fl = 0 );
public slots:
void setSelectedComponent( StructureComponent *component );
diff --git a/arts/builder/propertypanelbase.ui b/arts/builder/propertypanelbase.ui
index c89abcc6..b71d0bdb 100644
--- a/arts/builder/propertypanelbase.ui
+++ b/arts/builder/propertypanelbase.ui
@@ -1,11 +1,11 @@
<!DOCTYPE UI><UI version="3.0" stdsetdef="1">
<class>PropertyPanelBase</class>
<author>Hans Meine &lt;hans_meine@gmx.net&gt;</author>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>propertyPanelBase</cstring>
</property>
- <property name="geometry">
+ <property name="tqgeometry">
<rect>
<x>0</x>
<y>0</y>
@@ -13,9 +13,9 @@
<height>484</height>
</rect>
</property>
- <property name="layoutMargin" stdset="0">
+ <property name="tqlayoutMargin" stdset="0">
</property>
- <property name="layoutSpacing" stdset="0">
+ <property name="tqlayoutSpacing" stdset="0">
</property>
<vbox>
<property name="name">
@@ -27,7 +27,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QFrame">
+ <widget class="TQFrame">
<property name="name">
<cstring>titleFrame</cstring>
</property>
@@ -37,7 +37,7 @@
<property name="frameShadow">
<enum>Plain</enum>
</property>
- <property name="layoutMargin" stdset="0">
+ <property name="tqlayoutMargin" stdset="0">
</property>
<vbox>
<property name="name">
@@ -49,7 +49,7 @@
<property name="spacing">
<number>0</number>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>selectedLabel</cstring>
</property>
@@ -59,11 +59,11 @@
</widget>
</vbox>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>spacerLayout</cstring>
</property>
- <property name="layoutMargin" stdset="0">
+ <property name="tqlayoutMargin" stdset="0">
</property>
<vbox>
<property name="name">
@@ -75,7 +75,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>mainBoxLayout</cstring>
</property>
@@ -89,7 +89,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>Layout17</cstring>
</property>
@@ -103,7 +103,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>Layout13</cstring>
</property>
@@ -117,14 +117,14 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>moduleIconLabel</cstring>
</property>
</widget>
</vbox>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>Layout16</cstring>
</property>
@@ -138,12 +138,12 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>moduleNameLabel</cstring>
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>Layout10</cstring>
</property>
@@ -157,7 +157,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>portComboLabel</cstring>
</property>
@@ -168,7 +168,7 @@
<cstring>portCombo</cstring>
</property>
</widget>
- <widget class="QComboBox">
+ <widget class="TQComboBox">
<property name="name">
<cstring>portCombo</cstring>
</property>
@@ -198,7 +198,7 @@
</widget>
</hbox>
</widget>
- <widget class="QButtonGroup">
+ <widget class="TQButtonGroup">
<property name="name">
<cstring>portValueGroup</cstring>
</property>
@@ -215,7 +215,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QRadioButton">
+ <widget class="TQRadioButton">
<property name="name">
<cstring>pvNotSetButton</cstring>
</property>
@@ -223,7 +223,7 @@
<string>&amp;Not set</string>
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>Layout9</cstring>
</property>
@@ -237,7 +237,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QRadioButton">
+ <widget class="TQRadioButton">
<property name="name">
<cstring>pvConstantButton</cstring>
</property>
@@ -245,7 +245,7 @@
<string>Constant &amp;value:</string>
</property>
</widget>
- <widget class="QComboBox">
+ <widget class="TQComboBox">
<property name="name">
<cstring>constantValueComboBox</cstring>
</property>
@@ -253,7 +253,7 @@
<bool>false</bool>
</property>
</widget>
- <widget class="QLineEdit">
+ <widget class="TQLineEdit">
<property name="name">
<cstring>constantValueEdit</cstring>
</property>
@@ -263,7 +263,7 @@
</widget>
</hbox>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>connectionLayout</cstring>
</property>
@@ -277,7 +277,7 @@
<property name="spacing">
<number>6</number>
</property>
- <widget class="QRadioButton">
+ <widget class="TQRadioButton">
<property name="name">
<cstring>pvConnectionButton</cstring>
</property>
@@ -296,7 +296,7 @@
<enum>Expanding</enum>
</property>
</spacer>
- <widget class="QPushButton">
+ <widget class="TQPushButton">
<property name="name">
<cstring>connectButton</cstring>
</property>
@@ -310,11 +310,11 @@
</widget>
</hbox>
</widget>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>tipLabel</cstring>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>WordBreak|AlignVCenter|AlignLeft</set>
</property>
<property name="wordwrap" stdset="0">
@@ -355,8 +355,8 @@
<slot>setEnabled(bool)</slot>
</connection>
</connections>
-<slots>
+<Q_SLOTS>
<slot access="protected">setTitleFont()</slot>
-</slots>
-<layoutdefaults spacing="6" margin="11"/>
+</Q_SLOTS>
+<tqlayoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/arts/builder/qttableview.cpp b/arts/builder/qttableview.cpp
index dee8cb99..ca488ffb 100644
--- a/arts/builder/qttableview.cpp
+++ b/arts/builder/qttableview.cpp
@@ -7,14 +7,14 @@
**
** Copyright (C) 1992-2000 Trolltech AS. All rights reserved.
**
-** This file contains a class moved out of the Qt GUI Toolkit API. It
+** This file contains a class moved out of the TQt GUI Toolkit API. It
** may be used, distributed and modified without limitation.
**
**********************************************************************/
#include "qttableview.h"
#include "qttableview.moc"
-#ifndef QT_NO_QTTABLEVIEW
+#ifndef TQT_NO_TQTTABLEVIEW
#include "tqscrollbar.h"
#include "tqpainter.h"
#include "tqdrawutil.h"
@@ -34,23 +34,23 @@ enum ScrollBarDirtyFlags {
};
-#define HSBEXT horizontalScrollBar()->sizeHint().height()
-#define VSBEXT verticalScrollBar()->sizeHint().width()
+#define HSBEXT horizontalScrollBar()->tqsizeHint().height()
+#define VSBEXT verticalScrollBar()->tqsizeHint().width()
-class QCornerSquare : public QWidget // internal class
+class TQCornerSquare : public TQWidget // internal class
{
public:
- QCornerSquare( TQWidget *, const char* = 0 );
+ TQCornerSquare( TQWidget *, const char* = 0 );
void paintEvent( TQPaintEvent * );
};
-QCornerSquare::QCornerSquare( TQWidget *parent, const char *name )
- : TQWidget( parent, name )
+TQCornerSquare::TQCornerSquare( TQWidget *tqparent, const char *name )
+ : TQWidget( tqparent, name )
{
}
-void QCornerSquare::paintEvent( TQPaintEvent * )
+void TQCornerSquare::paintEvent( TQPaintEvent * )
{
}
@@ -88,7 +88,7 @@ void QCornerSquare::paintEvent( TQPaintEvent * )
used by functions such as setXOffset() or maxYOffset().
\i The \e widget coordinates. (0,0) is the top-left corner of the widget,
- \e including the frame. They are used by functions such as repaint().
+ \e including the frame. They are used by functions such as tqrepaint().
\i The \e view coordinates. (0,0) is the top-left corner of the view, \e
excluding the frame. This is the least-used coordinate system; it is used by
@@ -119,13 +119,13 @@ void QCornerSquare::paintEvent( TQPaintEvent * )
it easy to have child widgets inside tables, which QtTableView
doesn't support at all.
- \sa QScrollView
+ \sa TQScrollView
\link guibooks.html#fowler GUI Design Handbook: Table\endlink
*/
/*!
- Constructs a table view. The \a parent, \a name and \f arguments
+ Constructs a table view. The \a tqparent, \a name and \f arguments
are passed to the TQFrame constructor.
The \link setTableFlags() table flags\endlink are all cleared (set to 0).
@@ -135,7 +135,7 @@ void QCornerSquare::paintEvent( TQPaintEvent * )
The \link setCellHeight() cell height\endlink and \link setCellWidth()
cell width\endlink are set to 0.
- Frame line shapes (TQFrame::HLink and TQFrame::VLine) are disallowed;
+ Frame line tqshapes (TQFrame::HLink and TQFrame::VLine) are disallowed;
see TQFrame::setFrameStyle().
Note that the \a f argument is \e not \link setTableFlags() table
@@ -144,8 +144,8 @@ void QCornerSquare::paintEvent( TQPaintEvent * )
*/
-QtTableView::QtTableView( TQWidget *parent, const char *name, WFlags f )
- : TQFrame( parent, name, f )
+QtTableView::QtTableView( TQWidget *tqparent, const char *name, WFlags f )
+ : TQFrame( tqparent, name, f )
{
nRows = nCols = 0; // zero rows/cols
xCellOffs = yCellOffs = 0; // zero offset
@@ -207,7 +207,7 @@ void QtTableView::show()
/*!
- \overload void QtTableView::repaint( bool erase )
+ \overload void QtTableView::tqrepaint( bool erase )
Repaints the entire view.
*/
@@ -221,16 +221,16 @@ void QtTableView::show()
If \a w is negative, it is replaced with <code>width() - x</code>.
If \a h is negative, it is replaced with <code>height() - y</code>.
- Doing a repaint() usually is faster than doing an update(), but
+ Doing a tqrepaint() usually is faster than doing an update(), but
calling update() many times in a row will generate a single paint
event.
At present, QtTableView is the only widget that reimplements \link
- TQWidget::repaint() repaint()\endlink. It does this because by
- clearing and then repainting one cell at at time, it can make the
+ TQWidget::tqrepaint() tqrepaint()\endlink. It does this because by
+ clearing and then tqrepainting one cell at at time, it can make the
screen flicker less than it would otherwise. */
-void QtTableView::repaint( int x, int y, int w, int h, bool erase )
+void QtTableView::tqrepaint( int x, int y, int w, int h, bool erase )
{
if ( !isVisible() || testWState(WState_BlockUpdates) )
return;
@@ -249,7 +249,7 @@ void QtTableView::repaint( int x, int y, int w, int h, bool erase )
}
/*!
- \overload void QtTableView::repaint( const TQRect &r, bool erase )
+ \overload void QtTableView::tqrepaint( const TQRect &r, bool erase )
Replaints rectangle \a r. If \a erase is TRUE draws the background
using the palette's background.
*/
@@ -265,7 +265,7 @@ void QtTableView::repaint( int x, int y, int w, int h, bool erase )
Sets the number of rows of the table to \a rows (must be non-negative).
Does not change topCell().
- The table repaints itself automatically if autoUpdate() is set.
+ The table tqrepaints itself automatically if autoUpdate() is set.
\sa numCols(), setNumCols(), numRows()
*/
@@ -273,7 +273,7 @@ void QtTableView::repaint( int x, int y, int w, int h, bool erase )
void QtTableView::setNumRows( int rows )
{
if ( rows < 0 ) {
-#if defined(QT_CHECK_RANGE)
+#if defined(TQT_CHECK_RANGE)
qWarning( "QtTableView::setNumRows: (%s) Negative argument %d.",
name( "unnamed" ), rows );
#endif
@@ -288,7 +288,7 @@ void QtTableView::setNumRows( int rows )
nRows = rows;
if ( autoUpdate() && isVisible() &&
( oldLastVisible != lastRowVisible() || oldTopCell != topCell() ) )
- repaint( oldTopCell != topCell() );
+ tqrepaint( oldTopCell != topCell() );
} else {
// Be more careful - if destructing, bad things might happen.
nRows = rows;
@@ -307,7 +307,7 @@ void QtTableView::setNumRows( int rows )
Sets the number of columns of the table to \a cols (must be non-negative).
Does not change leftCell().
- The table repaints itself automatically if autoUpdate() is set.
+ The table tqrepaints itself automatically if autoUpdate() is set.
\sa numCols(), numRows(), setNumRows()
*/
@@ -315,7 +315,7 @@ void QtTableView::setNumRows( int rows )
void QtTableView::setNumCols( int cols )
{
if ( cols < 0 ) {
-#if defined(QT_CHECK_RANGE)
+#if defined(TQT_CHECK_RANGE)
qWarning( "QtTableView::setNumCols: (%s) Negative argument %d.",
name( "unnamed" ), cols );
#endif
@@ -328,7 +328,7 @@ void QtTableView::setNumCols( int cols )
if ( autoUpdate() && isVisible() ) {
int maxCol = lastColVisible();
if ( maxCol >= oldCols || maxCol >= nCols )
- repaint();
+ tqrepaint();
}
updateScrollBars( horRange );
updateFrameSize();
@@ -580,7 +580,7 @@ void QtTableView::setCellWidth( int cellWidth )
{
if ( cellW == cellWidth )
return;
-#if defined(QT_CHECK_RANGE)
+#if defined(TQT_CHECK_RANGE)
if ( cellWidth < 0 || cellWidth > SHRT_MAX ) {
qWarning( "QtTableView::setCellWidth: (%s) Argument out of range (%d)",
name( "unnamed" ), cellWidth );
@@ -591,7 +591,7 @@ void QtTableView::setCellWidth( int cellWidth )
updateScrollBars( horSteps | horRange );
if ( autoUpdate() && isVisible() )
- repaint();
+ tqrepaint();
}
@@ -634,7 +634,7 @@ void QtTableView::setCellHeight( int cellHeight )
{
if ( cellH == cellHeight )
return;
-#if defined(QT_CHECK_RANGE)
+#if defined(TQT_CHECK_RANGE)
if ( cellHeight < 0 || cellHeight > SHRT_MAX ) {
qWarning( "QtTableView::setCellHeight: (%s) Argument out of range (%d)",
name( "unnamed" ), cellHeight );
@@ -643,7 +643,7 @@ void QtTableView::setCellHeight( int cellHeight )
#endif
cellH = (short)cellHeight;
if ( autoUpdate() && isVisible() )
- repaint();
+ tqrepaint();
updateScrollBars( verSteps | verRange );
}
@@ -717,7 +717,7 @@ int QtTableView::totalHeight()
Sets the table flags to \a f.
If a flag setting changes the appearance of the table, the table is
- repainted if - and only if - autoUpdate() is TRUE.
+ tqrepainted if - and only if - autoUpdate() is TRUE.
The table flags are mostly single bits, though there are some multibit
flags for convenience. Here is a complete list:
@@ -786,7 +786,7 @@ void QtTableView::setTableFlags( uint f )
bool updateOn = autoUpdate();
setAutoUpdate( FALSE );
- uint repaintMask = Tbl_cutCellsV | Tbl_cutCellsH;
+ uint tqrepaintMask = Tbl_cutCellsV | Tbl_cutCellsH;
if ( f & Tbl_vScrollBar ) {
setVerScrollBar( TRUE );
@@ -817,15 +817,15 @@ void QtTableView::setTableFlags( uint f )
(f & Tbl_snapToVGrid) != 0 && yCellDelta != 0 ) {
snapToGrid( (f & Tbl_snapToHGrid) != 0, // do snapping
(f & Tbl_snapToVGrid) != 0 );
- repaintMask |= Tbl_snapToGrid; // repaint table
+ tqrepaintMask |= Tbl_snapToGrid; // tqrepaint table
}
}
if ( updateOn ) {
setAutoUpdate( TRUE );
updateScrollBars();
- if ( isVisible() && (f & repaintMask) )
- repaint();
+ if ( isVisible() && (f & tqrepaintMask) )
+ tqrepaint();
}
}
@@ -852,7 +852,7 @@ void QtTableView::clearTableFlags( uint f )
bool updateOn = autoUpdate();
setAutoUpdate( FALSE );
- uint repaintMask = Tbl_cutCellsV | Tbl_cutCellsH;
+ uint tqrepaintMask = Tbl_cutCellsV | Tbl_cutCellsH;
if ( f & Tbl_vScrollBar ) {
setVerScrollBar( FALSE );
@@ -864,7 +864,7 @@ void QtTableView::clearTableFlags( uint f )
int maxX = maxXOffset();
if ( xOffs > maxX ) {
setOffset( maxX, yOffs );
- repaintMask |= Tbl_scrollLastHCell;
+ tqrepaintMask |= Tbl_scrollLastHCell;
}
updateScrollBars( horRange );
}
@@ -872,7 +872,7 @@ void QtTableView::clearTableFlags( uint f )
int maxY = maxYOffset();
if ( yOffs > maxY ) {
setOffset( xOffs, maxY );
- repaintMask |= Tbl_scrollLastVCell;
+ tqrepaintMask |= Tbl_scrollLastVCell;
}
updateScrollBars( verRange );
}
@@ -881,7 +881,7 @@ void QtTableView::clearTableFlags( uint f )
(f & Tbl_smoothVScrolling) != 0 && yCellDelta != 0 ) {
snapToGrid( (f & Tbl_smoothHScrolling) != 0, // do snapping
(f & Tbl_smoothVScrolling) != 0 );
- repaintMask |= Tbl_smoothScrolling; // repaint table
+ tqrepaintMask |= Tbl_smoothScrolling; // tqrepaint table
}
}
if ( f & Tbl_snapToHGrid ) {
@@ -893,8 +893,8 @@ void QtTableView::clearTableFlags( uint f )
if ( updateOn ) {
setAutoUpdate( TRUE );
updateScrollBars(); // returns immediately if nothing to do
- if ( isVisible() && (f & repaintMask) )
- repaint();
+ if ( isVisible() && (f & tqrepaintMask) )
+ tqrepaint();
}
}
@@ -916,20 +916,20 @@ void QtTableView::clearTableFlags( uint f )
automatically whenever it has changed in some way (for example, when a
\link setTableFlags() flag\endlink is changed).
- If \a enable is FALSE, the view does NOT repaint itself or update
+ If \a enable is FALSE, the view does NOT tqrepaint itself or update
its internal state variables when it is changed. This can be
useful to avoid flicker during large changes and is singularly
useless otherwise. Disable auto-update, do the changes, re-enable
- auto-update and call repaint().
+ auto-update and call tqrepaint().
\warning Do not leave the view in this state for a long time
(i.e., between events). If, for example, the user interacts with the
view when auto-update is off, strange things can happen.
- Setting auto-update to TRUE does not repaint the view; you must call
- repaint() to do this.
+ Setting auto-update to TRUE does not tqrepaint the view; you must call
+ tqrepaint() to do this.
- \sa autoUpdate(), repaint()
+ \sa autoUpdate(), tqrepaint()
*/
void QtTableView::setAutoUpdate( bool enable )
@@ -948,7 +948,7 @@ void QtTableView::setAutoUpdate( bool enable )
Repaints the cell at row \a row, column \a col if it is inside the view.
If \a erase is TRUE, the relevant part of the view is cleared to the
- background color/pixmap before the contents are repainted.
+ background color/pixmap before the contents are tqrepainted.
\sa isVisible()
*/
@@ -963,7 +963,7 @@ void QtTableView::updateCell( int row, int col, bool erase )
TQRect uR = TQRect( xPos, yPos,
cellW ? cellW : cellWidth(col),
cellH ? cellH : cellHeight(row) );
- repaint( uR.intersect(viewRect()), erase );
+ tqrepaint( uR.intersect(viewRect()), erase );
}
@@ -1073,7 +1073,7 @@ void QtTableView::coverCornerSquare( bool enable )
{
coveringCornerSquare = enable;
if ( !cornerSquare && enable ) {
- cornerSquare = new QCornerSquare( this );
+ cornerSquare = new TQCornerSquare( this );
Q_CHECK_PTR( cornerSquare );
cornerSquare->setGeometry( maxViewX() + frameWidth() + 1,
maxViewY() + frameWidth() + 1,
@@ -1266,7 +1266,7 @@ void QtTableView::setupPainter( TQPainter * )
/*!
Handles paint events, \a e, for the table view.
- Calls paintCell() for the cells that needs to be repainted.
+ Calls paintCell() for the cells that needs to be tqrepainted.
*/
void QtTableView::paintEvent( TQPaintEvent *e )
@@ -1280,7 +1280,7 @@ void QtTableView::paintEvent( TQPaintEvent *e )
TQPainter paint( this );
- if ( !contentsRect().contains( updateR, TRUE ) ) {// update frame ?
+ if ( !contentsRect().tqcontains( updateR, TRUE ) ) {// update frame ?
drawFrame( &paint );
if ( updateR.left() < frameWidth() ) //###
updateR.setLeft( frameWidth() );
@@ -1315,7 +1315,7 @@ void QtTableView::paintEvent( TQPaintEvent *e )
TQRect winR = viewRect();
TQRect cellR;
TQRect cellUR;
-#ifndef QT_NO_TRANSFORMATIONS
+#ifndef TQT_NO_TRANSFORMATIONS
TQWMatrix matrix;
#endif
@@ -1339,11 +1339,11 @@ void QtTableView::paintEvent( TQPaintEvent *e )
if ( eraseInPaint )
paint.eraseRect( cellUR );
-#ifndef QT_NO_TRANSFORMATIONS
+#ifndef TQT_NO_TRANSFORMATIONS
matrix.translate( xPos, yPos );
paint.setWorldMatrix( matrix );
if ( testTableFlags(Tbl_clipCellPainting) ||
- frameWidth() > 0 && !winR.contains( cellR ) ) { //##arnt
+ frameWidth() > 0 && !winR.tqcontains( cellR ) ) { //##arnt
paint.setClipRect( cellUR );
paintCell( &paint, row, col );
paint.setClipping( FALSE );
@@ -1355,7 +1355,7 @@ void QtTableView::paintEvent( TQPaintEvent *e )
#else
paint.translate( xPos, yPos );
if ( testTableFlags(Tbl_clipCellPainting) ||
- frameWidth() > 0 && !winR.contains( cellR ) ) { //##arnt
+ frameWidth() > 0 && !winR.tqcontains( cellR ) ) { //##arnt
paint.setClipRect( cellUR );
paintCell( &paint, row, col );
paint.setClipping( FALSE );
@@ -1379,13 +1379,13 @@ void QtTableView::paintEvent( TQPaintEvent *e )
// Note that this needs to be done regardless whether we do
// eraseInPaint or not. Reason: a subclass may implement
- // flicker-freeness and encourage the use of repaint(FALSE).
+ // flicker-freeness and encourage the use of tqrepaint(FALSE).
// The subclass, however, cannot draw all pixels, just those
// inside the cells. So QtTableView is reponsible for all pixels
// outside the cells.
TQRect viewR = viewRect();
- const TQColorGroup g = colorGroup();
+ const TQColorGroup g = tqcolorGroup();
if ( xPos <= maxX ) {
TQRect r = viewR;
@@ -1414,8 +1414,8 @@ void QtTableView::resizeEvent( TQResizeEvent * )
verSteps | verGeometry | verRange );
showOrHideScrollBars();
updateFrameSize();
- int maxX = QMIN( xOffs, maxXOffset() ); // ### can be slow
- int maxY = QMIN( yOffs, maxYOffset() );
+ int maxX = TQMIN( xOffs, maxXOffset() ); // ### can be slow
+ int maxY = TQMIN( yOffs, maxYOffset() );
setOffset( maxX, maxY );
}
@@ -1426,7 +1426,7 @@ void QtTableView::resizeEvent( TQResizeEvent * )
void QtTableView::updateView()
{
- repaint( viewRect() );
+ tqrepaint( viewRect() );
}
/*!
@@ -1439,14 +1439,14 @@ TQScrollBar *QtTableView::verticalScrollBar() const
{
QtTableView *that = (QtTableView*)this; // semantic const
if ( !vScrollBar ) {
- TQScrollBar *sb = new TQScrollBar( TQScrollBar::Vertical, that );
-#ifndef QT_NO_CURSOR
+ TQScrollBar *sb = new TQScrollBar( Qt::Vertical, that );
+#ifndef TQT_NO_CURSOR
sb->setCursor( arrowCursor );
#endif
- sb->resize( sb->sizeHint() ); // height is irrelevant
+ sb->resize( sb->tqsizeHint() ); // height is irrelevant
Q_CHECK_PTR(sb);
sb->setTracking( FALSE );
- sb->setFocusPolicy( NoFocus );
+ sb->setFocusPolicy( TQ_NoFocus );
connect( sb, TQT_SIGNAL(valueChanged(int)),
TQT_SLOT(verSbValue(int)));
connect( sb, TQT_SIGNAL(sliderMoved(int)),
@@ -1470,12 +1470,12 @@ TQScrollBar *QtTableView::horizontalScrollBar() const
{
QtTableView *that = (QtTableView*)this; // semantic const
if ( !hScrollBar ) {
- TQScrollBar *sb = new TQScrollBar( TQScrollBar::Horizontal, that );
-#ifndef QT_NO_CURSOR
+ TQScrollBar *sb = new TQScrollBar( Qt::Horizontal, that );
+#ifndef TQT_NO_CURSOR
sb->setCursor( arrowCursor );
#endif
- sb->resize( sb->sizeHint() ); // width is irrelevant
- sb->setFocusPolicy( NoFocus );
+ sb->resize( sb->tqsizeHint() ); // width is irrelevant
+ sb->setFocusPolicy( TQ_NoFocus );
Q_CHECK_PTR(sb);
sb->setTracking( FALSE );
connect( sb, TQT_SIGNAL(valueChanged(int)),
@@ -1522,7 +1522,7 @@ void QtTableView::setHorScrollBar( bool on, bool update )
else
sbDirty = sbDirty | verMask;
if ( hideScrollBar && isVisible() )
- repaint( hScrollBar->x(), hScrollBar->y(),
+ tqrepaint( hScrollBar->x(), hScrollBar->y(),
width() - hScrollBar->x(), hScrollBar->height() );
}
if ( update )
@@ -1561,7 +1561,7 @@ void QtTableView::setVerScrollBar( bool on, bool update )
else
sbDirty = sbDirty | horMask;
if ( hideScrollBar && isVisible() )
- repaint( vScrollBar->x(), vScrollBar->y(),
+ tqrepaint( vScrollBar->x(), vScrollBar->y(),
vScrollBar->width(), height() - vScrollBar->y() );
}
if ( update )
@@ -1579,7 +1579,7 @@ int QtTableView::findRawRow( int yPos, int *cellMaxY, int *cellMinY,
return r;
if ( goOutsideView || yPos >= minViewY() && yPos <= maxViewY() ) {
if ( yPos < minViewY() ) {
-#if defined(QT_CHECK_RANGE)
+#if defined(TQT_CHECK_RANGE)
qWarning( "QtTableView::findRawRow: (%s) internal error: "
"yPos < minViewY() && goOutsideView "
"not supported. (%d,%d)",
@@ -1626,7 +1626,7 @@ int QtTableView::findRawCol( int xPos, int *cellMaxX, int *cellMinX ,
return c;
if ( goOutsideView || xPos >= minViewX() && xPos <= maxViewX() ) {
if ( xPos < minViewX() ) {
-#if defined(QT_CHECK_RANGE)
+#if defined(TQT_CHECK_RANGE)
qWarning( "QtTableView::findRawCol: (%s) internal error: "
"xPos < minViewX() && goOutsideView "
"not supported. (%d,%d)",
@@ -1995,7 +1995,7 @@ void QtTableView::updateScrollBars( uint f )
if ( sbDirty & horSteps ) {
if ( cellW )
- hScrollBar->setSteps( QMIN(cellW,viewWidth()/2), viewWidth() );
+ hScrollBar->setSteps( TQMIN(cellW,viewWidth()/2), viewWidth() );
else
hScrollBar->setSteps( 16, viewWidth() );
}
@@ -2006,7 +2006,7 @@ void QtTableView::updateScrollBars( uint f )
if ( sbDirty & horValue )
hScrollBar->setValue( xOffs );
- // show scrollbar only when it has a sane geometry
+ // show scrollbar only when it has a sane tqgeometry
if ( !hScrollBar->isVisible() )
hScrollBar->show();
}
@@ -2019,7 +2019,7 @@ void QtTableView::updateScrollBars( uint f )
if ( sbDirty & verSteps ) {
if ( cellH )
- vScrollBar->setSteps( QMIN(cellH,viewHeight()/2), viewHeight() );
+ vScrollBar->setSteps( TQMIN(cellH,viewHeight()/2), viewHeight() );
else
vScrollBar->setSteps( 16, viewHeight() ); // fttb! ###
}
@@ -2030,7 +2030,7 @@ void QtTableView::updateScrollBars( uint f )
if ( sbDirty & verValue )
vScrollBar->setValue( yOffs );
- // show scrollbar only when it has a sane geometry
+ // show scrollbar only when it has a sane tqgeometry
if ( !vScrollBar->isVisible() )
vScrollBar->show();
}
@@ -2061,9 +2061,9 @@ void QtTableView::updateFrameSize()
setFrameRect( TQRect(0,0,rw,rh) );
if ( rw != fw )
- update( QMIN(fw,rw) - frameWidth() - 2, 0, frameWidth()+4, rh );
+ update( TQMIN(fw,rw) - frameWidth() - 2, 0, frameWidth()+4, rh );
if ( rh != fh )
- update( 0, QMIN(fh,rh) - frameWidth() - 2, rw, frameWidth()+4 );
+ update( 0, TQMIN(fh,rh) - frameWidth() - 2, rw, frameWidth()+4 );
}
}
@@ -2253,7 +2253,7 @@ void QtTableView::showOrHideScrollBars()
Call this function when the table view's total size is changed;
typically because the result of cellHeight() or cellWidth() have changed.
- This function does not repaint the widget.
+ This function does not tqrepaint the widget.
*/
void QtTableView::updateTableSize()
diff --git a/arts/builder/qttableview.h b/arts/builder/qttableview.h
index ab83d152..a6e868b6 100644
--- a/arts/builder/qttableview.h
+++ b/arts/builder/qttableview.h
@@ -7,38 +7,37 @@
**
** Copyright (C) 1992-2000 Trolltech AS. All rights reserved.
**
-** This file contains a class moved out of the Qt GUI Toolkit API. It
+** This file contains a class moved out of the TQt GUI Toolkit API. It
** may be used, distributed and modified without limitation.
**
**********************************************************************/
-#ifndef QTTABLEVIEW_H
-#define QTTABLEVIEW_H
+#ifndef TQTTABLEVIEW_H
+#define TQTTABLEVIEW_H
-#ifndef QT_H
#include "tqframe.h"
-#endif // QT_H
-#ifndef QT_NO_QTTABLEVIEW
+#ifndef TQT_NO_TQTTABLEVIEW
class TQScrollBar;
-class QCornerSquare;
+class TQCornerSquare;
-class QtTableView : public QFrame
+class QtTableView : public TQFrame
{
Q_OBJECT
+ TQ_OBJECT
public:
virtual void setBackgroundColor( const TQColor & );
virtual void setPalette( const TQPalette & );
void show();
- void repaint( bool erase=TRUE );
- void repaint( int x, int y, int w, int h, bool erase=TRUE );
- void repaint( const TQRect &, bool erase=TRUE );
+ void tqrepaint( bool erase=TRUE );
+ void tqrepaint( int x, int y, int w, int h, bool erase=TRUE );
+ void tqrepaint( const TQRect &, bool erase=TRUE );
protected:
- QtTableView( TQWidget *parent=0, const char *name=0, WFlags f=0 );
+ QtTableView( TQWidget *tqparent=0, const char *name=0, WFlags f=0 );
~QtTableView();
int numRows() const;
@@ -78,8 +77,8 @@ protected:
void updateCell( int row, int column, bool erase=TRUE );
- QRect cellUpdateRect() const;
- QRect viewRect() const;
+ TQRect cellUpdateRect() const;
+ TQRect viewRect() const;
int lastRowVisible() const;
int lastColVisible() const;
@@ -162,14 +161,14 @@ private:
uint inSbUpdate : 1;
uint tFlags;
- QRect cellUpdateR;
+ TQRect cellUpdateR;
TQScrollBar *vScrollBar;
TQScrollBar *hScrollBar;
- QCornerSquare *cornerSquare;
+ TQCornerSquare *cornerSquare;
private: // Disabled copy constructor and operator=
-#if defined(Q_DISABLE_COPY)
+#if defined(TQ_DISABLE_COPY)
QtTableView( const QtTableView & );
QtTableView &operator=( const QtTableView & );
#endif
@@ -236,16 +235,16 @@ inline TQRect QtTableView::cellUpdateRect() const
inline bool QtTableView::autoUpdate() const
{ return isUpdatesEnabled(); }
-inline void QtTableView::repaint( bool erase )
-{ repaint( 0, 0, width(), height(), erase ); }
+inline void QtTableView::tqrepaint( bool erase )
+{ tqrepaint( 0, 0, width(), height(), erase ); }
-inline void QtTableView::repaint( const TQRect &r, bool erase )
-{ repaint( r.x(), r.y(), r.width(), r.height(), erase ); }
+inline void QtTableView::tqrepaint( const TQRect &r, bool erase )
+{ tqrepaint( r.x(), r.y(), r.width(), r.height(), erase ); }
inline void QtTableView::updateScrollBars()
{ updateScrollBars( 0 ); }
-#endif // QT_NO_QTTABLEVIEW
+#endif // TQT_NO_TQTTABLEVIEW
-#endif // QTTABLEVIEW_H
+#endif // TQTTABLEVIEW_H
diff --git a/arts/builder/retrievedlg.cpp b/arts/builder/retrievedlg.cpp
index 57cfde36..c54cbabd 100644
--- a/arts/builder/retrievedlg.cpp
+++ b/arts/builder/retrievedlg.cpp
@@ -37,33 +37,33 @@
#include <tqpushbutton.h>
static void min_size(TQWidget *w) {
- w->setMinimumSize(w->sizeHint());
+ w->setMinimumSize(w->tqsizeHint());
}
-RetrieveDlg::RetrieveDlg(TQWidget *parent) :TQDialog(parent,"X", TRUE)
+RetrieveDlg::RetrieveDlg(TQWidget *tqparent) :TQDialog(tqparent,"X", TRUE)
{
setCaption(i18n("Retrieve Structure From Server"));
- TQVBoxLayout *mainlayout = new TQVBoxLayout(this);
+ TQVBoxLayout *maintqlayout = new TQVBoxLayout(this);
// caption label: "Synthesis running..."
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
TQLabel *captionlabel = new TQLabel(this);
TQFont labelfont(captionlabel->font());
labelfont.setPointSize(labelfont.pointSize()*3/2);
captionlabel->setFont(labelfont);
captionlabel->setText(TQString(" ")+i18n("Published structures")+TQString(" "));
- captionlabel->setAlignment(AlignCenter);
+ captionlabel->tqsetAlignment(AlignCenter);
min_size(captionlabel);
- mainlayout->addWidget(captionlabel);
+ maintqlayout->addWidget(captionlabel);
// hruler
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
KSeparator *ruler2 = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(ruler2);
- mainlayout->addSpacing(5);
+ maintqlayout->addWidget(ruler2);
+ maintqlayout->addSpacing(5);
// listwidget
@@ -85,26 +85,26 @@ RetrieveDlg::RetrieveDlg(TQWidget *parent) :TQDialog(parent,"X", TRUE)
listbox->insertItem((*ni).c_str());
#endif
- mainlayout->addWidget(listbox);
+ maintqlayout->addWidget(listbox);
// hruler
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
KSeparator *ruler = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(ruler);
- mainlayout->addSpacing(5);
+ maintqlayout->addWidget(ruler);
+ maintqlayout->addSpacing(5);
// buttons
- TQHBoxLayout *buttonlayout = new TQHBoxLayout;
- mainlayout->addSpacing(5);
- mainlayout->addLayout(buttonlayout);
- mainlayout->addSpacing(5);
+ TQHBoxLayout *buttontqlayout = new TQHBoxLayout;
+ maintqlayout->addSpacing(5);
+ maintqlayout->addLayout(buttontqlayout);
+ maintqlayout->addSpacing(5);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addSpacing(5);
KButtonBox *bbox = new KButtonBox(this);
- bbox->addButton(KStdGuiItem::help(), this, TQT_SLOT( help() ));
+ bbox->addButton(KStdGuiItem::help(), TQT_TQOBJECT(this), TQT_SLOT( help() ));
bbox->addStretch(1);
TQButton *cancelbutton = bbox->addButton(KStdGuiItem::cancel());
@@ -113,12 +113,12 @@ RetrieveDlg::RetrieveDlg(TQWidget *parent) :TQDialog(parent,"X", TRUE)
TQButton *okbutton = bbox->addButton(KStdGuiItem::ok());
connect( okbutton, TQT_SIGNAL( clicked() ), TQT_SLOT(accept() ) );
- bbox->layout();
+ bbox->tqlayout();
- buttonlayout->addWidget(bbox);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addWidget(bbox);
+ buttontqlayout->addSpacing(5);
- mainlayout->freeze();
+ maintqlayout->freeze();
}
TQString RetrieveDlg::result()
@@ -127,7 +127,7 @@ TQString RetrieveDlg::result()
{
return(listbox->text(listbox->currentItem()));
}
- return TQString::null;
+ return TQString();
}
void RetrieveDlg::help()
diff --git a/arts/builder/retrievedlg.h b/arts/builder/retrievedlg.h
index e0a6eb0c..3ffa57ee 100644
--- a/arts/builder/retrievedlg.h
+++ b/arts/builder/retrievedlg.h
@@ -35,9 +35,10 @@
class RetrieveDlg :public TQDialog {
Q_OBJECT
+ TQ_OBJECT
TQListBox *listbox;
public:
- RetrieveDlg(TQWidget *parent);
+ RetrieveDlg(TQWidget *tqparent);
TQString result();
public slots:
void help();
diff --git a/arts/builder/structureport.cpp b/arts/builder/structureport.cpp
index 35b36b45..55c15211 100644
--- a/arts/builder/structureport.cpp
+++ b/arts/builder/structureport.cpp
@@ -104,8 +104,8 @@ void StructurePort::drawSegment(TQPainter *dest, int cellsize, int segment)
TQColor mcolor(43,43,168);
TQColor mcolorlight(164,176,242);
- TQColorGroup g( Qt::white, Qt::blue, mcolorlight, mcolor.dark(), mcolor,
- Qt::black, Qt::black );
+ TQColorGroup g( TQt::white, TQt::blue, mcolorlight, mcolor.dark(), mcolor,
+ TQt::black, TQt::black );
TQBrush fill( mcolor );
TQPen textpen(TQColor(255,255,180),1);
int border = cellsize/10;
@@ -117,7 +117,7 @@ void StructurePort::drawSegment(TQPainter *dest, int cellsize, int segment)
// Selection box
if(_selected)
{
- TQPen pen(Qt::white,1,Qt::DotLine);
+ TQPen pen(TQt::white,1,TQt::DotLine);
p.setPen(pen);
p.drawRect(0,boxtop,cellsize,cellsize/2);
@@ -126,7 +126,7 @@ void StructurePort::drawSegment(TQPainter *dest, int cellsize, int segment)
int textwidth;
TQString label=DrawUtils::cropText(&p, pname, cellsize-border*2, textwidth);
p.drawText(border,border+boxtop,cellsize-border-1,(cellsize/2-1)-2*border,
- Qt::AlignCenter,label);
+ TQt::AlignCenter,label);
int arrowwidth = cellsize/4;
@@ -195,7 +195,7 @@ d | |
a.setPoint(8,t,b+w+l);
a.setPoint(9,t,b+l);
*/
- p.setPen(Qt::NoPen);
+ p.setPen(TQt::NoPen);
p.setBrush(fbrush);
p.drawPolygon(a);
if(delta==1 && direction==0)
@@ -224,7 +224,7 @@ ModulePort *StructurePort::portAt(int segment, int x, int y)
assert(segment == 0);
TQPoint clickpoint(x,y);
- if(_port->clickrect.contains(clickpoint)) return _port;
+ if(_port->clickrect.tqcontains(clickpoint)) return _port;
return 0;
}
diff --git a/arts/builder/execdlg.cpp b/arts/builder/execdlg.cpp
index 6d2ea2bf..bad531aa 100644
--- a/arts/builder/execdlg.cpp
+++ b/arts/builder/execdlg.cpp
@@ -41,31 +41,31 @@
#ifndef KDE_USE_FINAL
static void min_size(TQWidget *w) {
- w->setMinimumSize(w->sizeHint());
+ w->setMinimumSize(w->tqsizeHint());
}
#endif
-ExecDlg::ExecDlg(TQWidget *parent, ExecutableStructure *structure)
- :TQDialog(parent,"X")
+ExecDlg::ExecDlg(TQWidget *tqparent, ExecutableStructure *structure)
+ :TQDialog(tqparent,"X")
/*, TRUE)*/
{
this->structure = structure;
setCaption(i18n("aRts Module Execution"));
- mainlayout = new TQVBoxLayout(this);
+ maintqlayout = new TQVBoxLayout(this);
// caption label: "Synthesis running..."
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
TQLabel *captionlabel = new TQLabel(this);
TQFont labelfont(captionlabel->font());
labelfont.setPointSize(labelfont.pointSize()*3/2);
captionlabel->setFont(labelfont);
captionlabel->setText(TQString(" ")+i18n("Synthesis running...")+TQString(" "));
- captionlabel->setAlignment(AlignCenter);
+ captionlabel->tqsetAlignment(AlignCenter);
min_size(captionlabel);
- mainlayout->addWidget(captionlabel);
+ maintqlayout->addWidget(captionlabel);
cpuusagelabel = new TQLabel(this);
cpuusagelabel->setText(i18n("CPU usage: unknown"));
@@ -78,44 +78,44 @@ ExecDlg::ExecDlg(TQWidget *parent, ExecutableStructure *structure)
cpuusagetimer->start( 2000, false );
min_size(cpuusagelabel);
- mainlayout->addWidget(cpuusagelabel);
+ maintqlayout->addWidget(cpuusagelabel);
-// ruler above the sliderlayout
+// ruler above the slidertqlayout
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
KSeparator* sep = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(sep);
- mainlayout->addSpacing(5);
+ maintqlayout->addWidget(sep);
+ maintqlayout->addSpacing(5);
// sliders, controlpanels
- sliderlayout = new TQVBoxLayout;
- mainlayout->addLayout(sliderlayout);
+ slidertqlayout = new TQVBoxLayout;
+ maintqlayout->addLayout(slidertqlayout);
#if 0 /* PORT */
this->GUIServer = GUIServer;
GUIServer->setGlobalParent(this);
- GUIServer->setGlobalLayout(sliderlayout);
+ GUIServer->setGlobalLayout(slidertqlayout);
#endif
-// hruler below the sliderlayout
+// hruler below the slidertqlayout
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
sep = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(sep);
- mainlayout->addSpacing(5);
+ maintqlayout->addWidget(sep);
+ maintqlayout->addSpacing(5);
// buttons
- TQHBoxLayout *buttonlayout = new TQHBoxLayout;
- mainlayout->addSpacing(5);
- mainlayout->addLayout(buttonlayout);
- mainlayout->addSpacing(5);
+ TQHBoxLayout *buttontqlayout = new TQHBoxLayout;
+ maintqlayout->addSpacing(5);
+ maintqlayout->addLayout(buttontqlayout);
+ maintqlayout->addSpacing(5);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addSpacing(5);
KButtonBox *bbox = new KButtonBox(this);
- bbox->addButton(KStdGuiItem::help(), this, TQT_SLOT( help() ));
+ bbox->addButton(KStdGuiItem::help(), TQT_TQOBJECT(this), TQT_SLOT( help() ));
bbox->addStretch(1);
@@ -125,18 +125,18 @@ ExecDlg::ExecDlg(TQWidget *parent, ExecutableStructure *structure)
TQButton *okbutton = bbox->addButton(KStdGuiItem::ok());
connect( okbutton, TQT_SIGNAL( clicked() ), TQT_SLOT(accept() ) );
- bbox->layout();
+ bbox->tqlayout();
//min_size(bbox);
- buttonlayout->addWidget(bbox);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addWidget(bbox);
+ buttontqlayout->addSpacing(5);
-// mainlayout->freeze();
+// maintqlayout->freeze();
}
void ExecDlg::start()
{
- mainlayout->freeze();
+ maintqlayout->freeze();
}
void ExecDlg::guiServerTick()
@@ -151,7 +151,7 @@ void ExecDlg::updateCpuUsage()
#if 0 /* TODO:PORT */
char cpuusage[100];
- ArtsCorba::Status s = Synthesizer->getStatus();
+ ArtsCorba::tqStatus s = Synthesizer->gettqStatus();
if(s.halted)
{
cpuusagetimer->stop();